==> distfun-0.3-1-src.zip: distfun/src/cdflib/cumnbn.c <==
/* cumnbn.f -- translated by f2c (version 20100827). */

#include "cdflib.h"

/* Subroutine */ int cumnbn_(double *s, double *xn, double *pr, 
	double *ompr, double *cum, double *ccum)
{
	/* System generated locals */
	double d__1;

	/* Local variables */

	/* ********************************************************************** */

	/*     SUBROUTINE CUMNNBN(S,XN,PR,OMPR,CUM,CCUM) */
	/*                    CUmulative Negative BINomial distribution */


	/*                              Function */


	/*     Returns the probability that it there will be S or fewer failures */
	/*     before there are XN successes, with each binomial trial having */
	/*     a probability of success PR. */

	/*     Prob(# failures = S | XN successes, PR)  = */
	/*                        ( XN + S - 1 ) */
	/*                        (            ) * PR^XN * (1-PR)^S */
	/*                        (      S     ) */


	/*                              Arguments */


	/*     S --> The number of failures */
	/*                                                  S is DOUBLE PRECISION */

	/*     XN --> The number of successes */
	/*                                                  XN is DOUBLE PRECISIO */

	/*     PR --> The probability of success in each binomial trial. */
	/*                                                  PR is DOUBLE PRECISIO */

	/*     OMPR --> 1 - PR */
	/*                                                  OMPR is DOUBLE PRECIS */

	/*     CUM <-- Cumulative negative binomial distribution. */
	/*                                                  CUM is DOUBLE PRECISI */

	/*     CCUM <-- Compliment of Cumulative negative binomial distribution. */
	/*                                                  CCUM is DOUBLE PRECIS */


	/*                              Method */


	/*     Formula  26.5.26    of   Abramowitz  and    Stegun,  Handbook   of */
	/*     Mathematical   Functions (1966) is   used  to reduce the  negative */
	/*     binomial distribution to the cumulative beta distribution. */

	/* ********************************************************************** */
	/*     .. Scalar Arguments .. */
	/*     .. */

	/*     .. */
	/*     .. Executable Statements .. */
	d__1 = *s + 1.;
	cumbet_(pr, ompr, xn, &d__1, cum, ccum);
	return 0;
} /* cumnbn_ */

==> distfun-0.5-1-src.zip: distfun/src/cdflib/cumnbn.c <==
/* cumnbn.f -- translated by f2c (version 20100827).
with manual tuning by Michael Baudin (2012)
  */

#include "cdflib.h"
#include "cdflib_private.h" 

/* Subroutine */ int cdflib_cumnbn(double x, double xn, double pr, 
	double ompr, double *cum, double *ccum)
{
	/* System generated locals */
	double d__1;

	/* Local variables */

	/* ********************************************************************** */

	/*     SUBROUTINE CUMNNBN(X,XN,PR,OMPR,CUM,CCUM) */
	/*                    CUmulative Negative BINomial distribution */


	/*                              Function */


	/*     Returns the probability that it there will be X or fewer failures */
	/*     before there are XN successes, with each binomial trial having */
	/*     a probability of success PR. */

	/*     Prob(# failures = X | XN successes, PR)  = */
	/*                        ( XN + X - 1 ) */
	/*                        (            ) * PR^XN * (1-PR)^X */
	/*                        (      X     ) */


	/*                              Arguments */


	/*     X --> The number of failures */


	/*     XN --> The number of successes */

	/*     PR --> The probability of success in each binomial trial. */

	/*     OMPR --> 1 - PR */

	/*     CUM <-- Cumulative negative binomial distribution. */

	/*     CCUM <-- Compliment of Cumulative negative binomial distribution. */


	/*                              Method */


	/*     Formula  26.5.26    of   Abramowitz  and    Stegun,  Handbook   of */
	/*     Mathematical   Functions (1966) is   used  to reduce the  negative */
	/*     binomial distribution to the cumulative beta distribution. */

	/* ********************************************************************** */

	d__1 = x + 1.;
	cdflib_cumbet(pr, ompr, xn, d__1, cum, ccum);
	return 0;
}
